@@ -1,12 +1,10 @@
 package Mojolicious::Plugin::Prove;
-
+$Mojolicious::Plugin::Prove::VERSION = '0.11';
 # ABSTRACT: run test scripts via browser
 
 use Mojo::Base 'Mojolicious::Plugin::Prove::Base';
 use Mojo::File;
 
-our $VERSION = 0.10;
-
 sub register {
     my ($self, $app, $conf) = @_;
     
@@ -38,7 +36,7 @@ sub register {
     
     
     {
-        my $pr = $r->route("/$prefix")->to(
+        my $pr = $r->any("/$prefix")->to(
             'controller#',
             namespace => 'Mojolicious::Plugin::Prove',
             plugin    => $self,
@@ -68,7 +66,7 @@ Mojolicious::Plugin::Prove - run test scripts via browser
 
 =head1 VERSION
 
-version 0.1
+version 0.11
 
 =head1 SYNOPSIS
 
